@@ -5,9 +5,9 @@ from django.urls import URLPattern, URLResolver
 from rest_framework import views, viewsets
 from rest_framework.schemas.generators import BaseSchemaGenerator  # type: ignore
 from rest_framework.schemas.generators import EndpointEnumerator as BaseEndpointEnumerator
-from rest_framework.test import APIRequestFactory
 
 from drf_spectacular.extensions import OpenApiViewExtension
+from drf_spectacular.openapi import AutoSchema
 from drf_spectacular.plumbing import (
     ComponentRegistry, alpha_operation_sorter, build_root_object, camelize_operation, error,
     is_versioning_supported, modify_for_versioning, normalize_result_object,
@@ -79,11 +79,15 @@ class SchemaGenerator(BaseSchemaGenerator):
         """
         override_view = OpenApiViewExtension.get_match(callback.cls)
         if override_view:
+            original_cls = callback.cls
             callback.cls = override_view.view_replacement()
 
         view = super().create_view(callback, method, request)
 
-        if isinstance(view, viewsets.GenericViewSet) or isinstance(view, viewsets.ViewSet):
+        if override_view:
+            callback.cls = original_cls
+
+        if isinstance(view, viewsets.ViewSetMixin):
             action = getattr(view, view.action)
         elif isinstance(view, views.APIView):
             action = getattr(view, method.lower())
@@ -131,8 +135,7 @@ class SchemaGenerator(BaseSchemaGenerator):
             # mocked request to allow certain operations in get_queryset and get_serializer[_class]
             # without exceptions being raised due to no request.
             if not request:
-                request = getattr(APIRequestFactory(), method.lower())(path=path)
-                request = view.initialize_request(request)
+                request = spectacular_settings.GET_MOCK_REQUEST(method, path, view, request)
 
             view.request = request
 
@@ -147,11 +150,17 @@ class SchemaGenerator(BaseSchemaGenerator):
                     or getattr(request, 'version', None)  # incoming request was versioned
                     or view.versioning_class.default_version  # fallback
                 )
+                if not version:
+                    continue
                 path = modify_for_versioning(self.inspector.patterns, method, path, view, version)
-                if not version or not operation_matches_version(view, version):
+                if not operation_matches_version(view, version):
                     continue
 
-            # beware that every access to schema yields a fresh object (descriptor pattern)
+            assert isinstance(view.schema, AutoSchema), (
+                'Incompatible AutoSchema used on View. Is DRF\'s DEFAULT_SCHEMA_CLASS '
+                'pointing to "drf_spectacular.openapi.AutoSchema" or any other drf-spectacular '
+                'compatible AutoSchema?'
+            )
             operation = view.schema.get_operation(path, path_regex, method, self.registry)
 
             # operation was manually removed via @extend_schema
