@@ -222,8 +222,10 @@ class AutoSchema(ViewInspector):
                 object=authenticator.__class__,
                 schema=scheme.get_security_definition(self)
             )
-            if component not in self.registry:
-                self.registry.register(component)
+            self.registry.register_on_missing(component)
+
+        if spectacular_settings.SECURITY:
+            auths.extend(spectacular_settings.SECURITY)
 
         perms = [p.__class__ for p in self.view.get_permissions()]
         if permissions.AllowAny in perms:
@@ -307,9 +309,6 @@ class AutoSchema(ViewInspector):
                     model = get_view_model(self.view)
                     model_field = model._meta.get_field(variable)
                     schema = self._map_model_field(model_field, direction=None)
-                    # strip irrelevant meta data
-                    irrelevant_field_meta = ['readOnly', 'writeOnly', 'nullable', 'default']
-                    schema = {k: v for k, v in schema.items() if k not in irrelevant_field_meta}
                     if 'description' not in schema and model_field.primary_key:
                         description = get_pk_description(model, model_field)
                 except django_exceptions.FieldDoesNotExist:
@@ -459,23 +458,20 @@ class AutoSchema(ViewInspector):
             return append_meta(build_basic_type(OpenApiTypes.URI), meta)
 
         if isinstance(field, serializers.MultipleChoiceField):
-            return append_meta(build_array_type(build_choice_field(field.choices)), meta)
+            return append_meta(build_array_type(build_choice_field(field)), meta)
 
         if isinstance(field, serializers.ChoiceField):
-            return append_meta(build_choice_field(field.choices), meta)
+            return append_meta(build_choice_field(field), meta)
 
         if isinstance(field, serializers.ListField):
-            schema = build_array_type({})
-            # TODO check this
-            if not isinstance(field.child, _UnvalidatedField):
-                map_field = self._map_serializer_field(field.child, direction)
-                items = {
-                    "type": map_field.get('type')
-                }
-                if 'format' in map_field:
-                    items['format'] = map_field.get('format')
-                schema['items'] = items
-            return append_meta(schema, meta)
+            if isinstance(field.child, _UnvalidatedField):
+                return append_meta(build_array_type({}), meta)
+            elif is_serializer(field.child):
+                component = self.resolve_serializer(field.child, direction)
+                return append_meta(build_array_type(component.ref), meta) if component else None
+            else:
+                schema = self._map_serializer_field(field.child, direction)
+                return append_meta(build_array_type(schema), meta)
 
         # DateField and DateTimeField type is string
         if isinstance(field, serializers.DateField):
@@ -899,7 +895,18 @@ class AutoSchema(ViewInspector):
         if self._is_list_view(serializer) and not get_override(serializer, 'many') is False:
             schema = build_array_type(schema)
             paginator = self._get_paginator()
-            if paginator:
+
+            if paginator and is_serializer(serializer):
+                paginated_name = f'Paginated{self._get_serializer_name(serializer, "response")}List'
+                component = ResolvedComponent(
+                    name=paginated_name,
+                    type=ResolvedComponent.SCHEMA,
+                    schema=paginator.get_paginated_response_schema(schema),
+                    object=paginated_name,
+                )
+                self.registry.register(component)
+                schema = component.ref
+            elif paginator:
                 schema = paginator.get_paginated_response_schema(schema)
 
         return {
