@@ -12,8 +12,8 @@ from typing import DefaultDict, Generic, List, Optional, Type, TypeVar, Union
 
 import inflection
 import uritemplate
-from django import __version__ as DJANGO_VERSION
 from django.apps import apps
+from django.db.models.fields.reverse_related import ForeignObjectRel
 from django.urls.resolvers import (  # type: ignore
     _PATH_PARAMETER_COMPONENT_RE, RegexPattern, Resolver404, RoutePattern, URLPattern, URLResolver,
     get_resolver,
@@ -21,6 +21,8 @@ from django.urls.resolvers import (  # type: ignore
 from django.utils.functional import Promise
 from django.utils.module_loading import import_string
 from rest_framework import exceptions, fields, mixins, serializers, versioning
+from rest_framework.test import APIRequestFactory
+from rest_framework.utils.mediatypes import _MediaType
 from uritemplate import URITemplate
 
 from drf_spectacular.settings import spectacular_settings
@@ -246,10 +248,11 @@ def build_parameter_type(
         explode=None,
         style=None
 ):
+    irrelevant_field_meta = ['readOnly', 'writeOnly', 'nullable', 'default']
     schema = {
         'in': location,
         'name': name,
-        'schema': schema,
+        'schema': {k: v for k, v in schema.items() if k not in irrelevant_field_meta},
     }
     if description:
         schema['description'] = description
@@ -266,8 +269,9 @@ def build_parameter_type(
     return schema
 
 
-def build_choice_field(choices):
-    choices = list(OrderedDict.fromkeys(choices))  # preserve order and remove duplicates
+def build_choice_field(field):
+    choices = list(OrderedDict.fromkeys(field.choices))  # preserve order and remove duplicates
+
     if all(isinstance(choice, bool) for choice in choices):
         type = 'boolean'
     elif all(isinstance(choice, int) for choice in choices):
@@ -280,6 +284,11 @@ def build_choice_field(choices):
     else:
         type = None
 
+    if field.allow_blank:
+        choices.append('')
+    if field.allow_null:
+        choices.append(None)
+
     schema = {
         # The value of `enum` keyword MUST be an array and SHOULD be unique.
         # Ref: https://tools.ietf.org/html/draft-wright-json-schema-validation-00#section-5.20
@@ -316,8 +325,6 @@ def build_root_object(paths, components):
         root['info']['license'] = settings.LICENSE
     if settings.SERVERS:
         root['servers'] = settings.SERVERS
-    if settings.SECURITY:
-        root['security'] = settings.SECURITY
     if settings.TAGS:
         root['tags'] = settings.TAGS
     if settings.EXTERNAL_DOCS:
@@ -339,19 +346,11 @@ def append_meta(schema, meta):
     return safe_ref({**schema, **meta})
 
 
-def get_field_from_model(model, field):
+def _follow_field_source(model, path: List[str]):
     """
-    this is a Django 2.2 compatibility function to access a field through a Deferred Attribute
+        navigate through root model via given navigation path. supports forward/reverse relations.
     """
-    if DJANGO_VERSION.startswith('2'):
-        # field.field will in effect return self, i.e. a DeferredAttribute again (loop)
-        return model._meta.get_field(field.field_name)
-    else:
-        return field.field
-
-
-def _follow_field_source(model, path):
-    field_or_property = getattr(model, path[0])
+    field_or_property = getattr(model, path[0], None)
 
     if len(path) == 1:
         # end of traversal
@@ -360,7 +359,12 @@ def _follow_field_source(model, path):
         elif callable(field_or_property):
             return field_or_property
         else:
-            return get_field_from_model(model, field_or_property)
+            field = model._meta.get_field(path[0])
+            if isinstance(field, ForeignObjectRel):
+                # resolve DRF internal object to PK field as approximation
+                return field.get_related_field()  # type: ignore
+            else:
+                return field
     else:
         if isinstance(field_or_property, property) or callable(field_or_property):
             if isinstance(field_or_property, property):
@@ -375,7 +379,7 @@ def _follow_field_source(model, path):
                 )
             return _follow_field_source(target_model, path[1:])
         else:
-            target_model = field_or_property.field.related_model
+            target_model = model._meta.get_field(path[0]).related_model
             return _follow_field_source(target_model, path[1:])
 
 
@@ -457,6 +461,10 @@ class ComponentRegistry:
             )
         self._components[component.key] = component
 
+    def register_on_missing(self, component: ResolvedComponent):
+        if component.key not in self._components:
+            self._components[component.key] = component
+
     def __contains__(self, component):
         if component.key not in self._components:
             return False
@@ -639,6 +647,7 @@ def operation_matches_version(view, requested_version):
 
 def modify_for_versioning(patterns, method, path, view, requested_version):
     assert view.versioning_class and view.request
+    assert requested_version
 
     view.request.version = requested_version
 
@@ -658,11 +667,17 @@ def modify_for_versioning(patterns, method, path, view, requested_version):
         except Resolver404:
             error(f"namespace versioning path resolution failed for {path}. path will be ignored.")
     elif issubclass(view.versioning_class, versioning.AcceptHeaderVersioning):
-        renderer = view.get_renderers()[0]
-        view.request.META['HTTP_ACCEPT'] = f'{renderer.media_type}; version={requested_version}'
-
-        negotiated = view.perform_content_negotiation(view.request)
-        view.request.accepted_renderer, view.request.accepted_media_type = negotiated
+        # Append the version into request accepted_media_type.
+        # e.g "application/json; version=1.0"
+        # To allow the AcceptHeaderVersioning negotiator going through.
+        if not hasattr(view.request, 'accepted_renderer'):
+            # Probably a mock request, content negotation was not performed, so, we do it now.
+            negotiated = view.perform_content_negotiation(view.request)
+            view.request.accepted_renderer, view.request.accepted_media_type = negotiated
+        media_type = _MediaType(view.request.accepted_media_type)
+        view.request.accepted_media_type = (
+            f'{media_type.full_type}; {view.versioning_class.version_param}={requested_version}'
+        )
 
     return path
 
@@ -676,7 +691,7 @@ def detype_pattern(pattern):
     if isinstance(pattern, URLResolver):
         return URLResolver(
             pattern=detype_pattern(pattern.pattern),
-            urlconf_name=[detype_pattern(p) for p in pattern.urlconf_name],
+            urlconf_name=[detype_pattern(p) for p in pattern.url_patterns],
             default_kwargs=pattern.default_kwargs,
             app_name=pattern.app_name,
             namespace=pattern.namespace,
@@ -696,7 +711,7 @@ def detype_pattern(pattern):
         )
     elif isinstance(pattern, RegexPattern):
         return RegexPattern(
-            regex=re.sub(r'\(\?P<(\w+)>.*\)', r'(?P<\1>[^/]+)', pattern._regex),
+            regex=re.sub(r'\(\?P<(\w+)>.+?\)', r'(?P<\1>[^/]+)', pattern._regex),
             name=pattern.name,
             is_endpoint=pattern._is_endpoint
         )
@@ -747,3 +762,9 @@ def camelize_operation(path, operation):
     operation['operationId'] = inflection.camelize(operation['operationId'], False)
 
     return path, operation
+
+
+def build_mock_request(method, path, view, original_request, **kwargs):
+    request = getattr(APIRequestFactory(), method.lower())(path=path)
+    request = view.initialize_request(request)
+    return request
