@@ -28,10 +28,24 @@ SPECTACULAR_DEFAULTS: Dict[str, Any] = {
     'SERVE_INCLUDE_SCHEMA': True,
     'SERVE_PERMISSIONS': ['rest_framework.permissions.AllowAny'],
 
+    # Dictionary of configurations to pass to the SwaggerUI({ ... })
+    # https://swagger.io/docs/open-source-tools/swagger-ui/usage/configuration/
+    'SWAGGER_UI_SETTINGS': {
+        'deepLinking': True,
+    },
+    'SWAGGER_UI_DIST': '//unpkg.com/swagger-ui-dist@3.35.1',
+    'SWAGGER_UI_FAVICON_HREF': '//unpkg.com/swagger-ui-dist@3.35.1/favicon-32x32.png',
+
     # Append OpenAPI objects to path and components in addition to the generated objects
     'APPEND_PATHS': {},
     'APPEND_COMPONENTS': {},
 
+    # DISCOURAGED - please don't use this anymore as it has tricky implications that
+    # are hard to get right. For authentication, OpenApiAuthenticationExtension are
+    # strongly preferred because they are more robust and easy to write.
+    # However if used, the list of methods is appended to every endpoint in the schema!
+    'SECURITY': [],
+
     # Postprocessing functions that run at the end of schema generation.
     # must satisfy interface result = hook(generator, request, public, result)
     'POSTPROCESSING_HOOKS': [
@@ -50,6 +64,11 @@ SPECTACULAR_DEFAULTS: Dict[str, Any] = {
     # function that returns a list of all classes that should be excluded from doc string extraction
     'GET_LIB_DOC_EXCLUDES': 'drf_spectacular.plumbing.get_lib_doc_excludes',
 
+    # Function that returns a mocked request for view processing. For CLI usage
+    # original_request will be None.
+    # interface: request = build_mock_request(method, path, view, original_request, **kwargs)
+    'GET_MOCK_REQUEST': 'drf_spectacular.plumbing.build_mock_request',
+
     # Camelize names like operationId and path parameter names
     'CAMELIZE_NAMES': False,
 
@@ -66,7 +85,6 @@ SPECTACULAR_DEFAULTS: Dict[str, Any] = {
     # Optional list of servers.
     # Each entry MUST contain "url", MAY contain "description", "variables"
     'SERVERS': [],
-    'SECURITY': None,
     # Tags defined in the global scope
     'TAGS': [],
     # Optional: MUST contain 'url', may contain "description"
@@ -88,6 +106,7 @@ IMPORT_STRINGS = [
     'POSTPROCESSING_HOOKS',
     'PREPROCESSING_HOOKS',
     'GET_LIB_DOC_EXCLUDES',
+    'GET_MOCK_REQUEST',
 ]
 
 spectacular_settings = APISettings(
