@@ -24,6 +24,13 @@ class Aux(models.Model):
     field_foreign = models.ForeignKey('Aux', null=True, on_delete=models.CASCADE)
 
 
+class AuxSerializer(serializers.ModelSerializer):
+    """ description for aux object """
+    class Meta:
+        fields = '__all__'
+        model = Aux
+
+
 class AllFields(models.Model):
     # basics
     field_int = models.IntegerField()
@@ -77,6 +84,10 @@ class AllFields(models.Model):
     def field_list(self):
         return [1.1, 2.2, 3.3]
 
+    @property
+    def field_list_object(self):
+        return self.field_m2m.all()
+
     def model_function_basic(self) -> bool:
         return True
 
@@ -107,6 +118,10 @@ class AllFieldsSerializer(serializers.ModelSerializer):
     field_list = serializers.ListField(
         child=serializers.FloatField(), min_length=3, max_length=100,
     )
+    field_list_serializer = serializers.ListField(
+        child=AuxSerializer(),
+        source='field_list_object',
+    )
 
     # extra related fields
     field_related_slug = serializers.SlugRelatedField(
@@ -150,13 +165,6 @@ class AllFieldsSerializer(serializers.ModelSerializer):
         model = AllFields
 
 
-class AuxSerializer(serializers.ModelSerializer):
-    """ description for aux object """
-    class Meta:
-        fields = '__all__'
-        model = Aux
-
-
 class AllFieldsModelViewset(viewsets.ReadOnlyModelViewSet):
     serializer_class = AllFieldsSerializer
     queryset = AllFields.objects.all()
