@@ -2,7 +2,6 @@ import uuid
 from unittest import mock
 
 import pytest
-from django.conf.urls import url
 from django.db import models
 from django.db.models import fields
 from django.urls import path, re_path
@@ -78,8 +77,8 @@ def test_free_form_responses(no_warnings):
             pass  # pragma: no cover
 
     generator = SchemaGenerator(patterns=[
-        url(r'^x$', XAPIView.as_view(), name='x'),
-        url(r'^y$', YAPIView.as_view(), name='y'),
+        re_path(r'^x$', XAPIView.as_view(), name='x'),
+        re_path(r'^y$', YAPIView.as_view(), name='y'),
     ])
     schema = generator.get_schema(request=None, public=True)
     validate_schema(schema)
@@ -99,7 +98,7 @@ def test_append_extra_components(no_warnings):
             pass  # pragma: no cover
 
     generator = SchemaGenerator(patterns=[
-        url(r'^x$', XAPIView.as_view(), name='x'),
+        re_path(r'^x$', XAPIView.as_view(), name='x'),
     ])
     schema = generator.get_schema(request=None, public=True)
     assert len(schema['components']['schemas']) == 2
@@ -811,7 +810,7 @@ def test_auto_schema_and_extend_parameters(no_warnings):
         def get_override_parameters(self):
             return [
                 OpenApiParameter("id", str, OpenApiParameter.PATH),
-                OpenApiParameter("foo", str),
+                OpenApiParameter("foo", str, deprecated=True),
                 OpenApiParameter("bar", str),
             ]
 
@@ -831,6 +830,7 @@ def test_auto_schema_and_extend_parameters(no_warnings):
     parameters = schema['paths']['/x/']['get']['parameters']
     assert parameters[0]['name'] == 'bar' and parameters[0]['schema']['type'] == 'integer'
     assert parameters[1]['name'] == 'foo' and parameters[1]['schema']['type'] == 'string'
+    assert parameters[1]['deprecated'] is True
     assert parameters[2]['name'] == 'id'
 
 
@@ -974,7 +974,7 @@ def test_queryset_filter_and_ordering_only_on_list(no_warnings):
     assert list_parameters[0]['name'] == 'id'
 
 
-def test_pagination_only_on_list(no_warnings):
+def test_pagination(no_warnings):
     class M6(models.Model):
         pass
 
@@ -990,11 +990,41 @@ def test_pagination_only_on_list(no_warnings):
 
     schema = generate_schema('x', XViewset)
 
+    # query params only on list
     retrieve_parameters = schema['paths']['/x/']['get']['parameters']
     assert len(retrieve_parameters) == 2
     assert retrieve_parameters[0]['name'] == 'limit'
     assert retrieve_parameters[1]['name'] == 'offset'
 
+    # no query params on retrieve
     list_parameters = schema['paths']['/x/{id}/']['get']['parameters']
     assert len(list_parameters) == 1
     assert list_parameters[0]['name'] == 'id'
+
+    # substituted component on list
+    assert 'X' in schema['components']['schemas']
+    assert 'PaginatedXList' in schema['components']['schemas']
+    substitution = schema['components']['schemas']['PaginatedXList']
+    assert substitution['type'] == 'object'
+    assert substitution['properties']['results']['items']['$ref'] == '#/components/schemas/X'
+
+
+@mock.patch(
+    'drf_spectacular.settings.spectacular_settings.SECURITY',
+    [{'apiKeyAuth': []}]
+)
+@mock.patch(
+    'drf_spectacular.settings.spectacular_settings.APPEND_COMPONENTS',
+    {"securitySchemes": {"apiKeyAuth": {"type": "apiKey", "in": "header", "name": "Authorization"}}}
+)
+def test_manual_security_method_addition(no_warnings):
+    @extend_schema(responses=OpenApiTypes.FLOAT)
+    @api_view(['GET'])
+    def view_func(request, format=None):
+        pass  # pragma: no cover
+
+    schema = generate_schema('/x/', view_function=view_func)
+    operation_security = schema['paths']['/x/']['get']['security']
+    schema_security = schema['components']['securitySchemes']
+    assert len(operation_security) == 4 and any(['apiKeyAuth' in os for os in operation_security])
+    assert len(schema_security) == 3 and 'apiKeyAuth' in schema_security
